@@ -74,6 +74,17 @@ class Netctl(object):
         if os.path.exists(cfile):
             return NetctlInterface(cfgfile=cfile, name=name)
 
+    def deleteIf(self, interfaceName):
+        dev = self.getInterface(interfaceName)
+        if dev != None:
+            if dev.enabled:
+                dev.disable()
+                dev.stop()
+            os.remove(dev._cfgFile)
+        dev = self.getInterface(interfaceName)
+        return dev == None
+
+
 class NetctlInterface(object):
 
     @classmethod
@@ -338,7 +349,7 @@ class Netdev(object):
     def _getData(self):
         self.ip = []
         self.ip6 = []
-        out = exec("ip addr show dev {}".format(self.dev))
+        out = run('ip addr show dev {}'.format(self.dev))
         if out.rc == 0:
             for line in out.stdout:
                 line = line.strip()
