@@ -31,6 +31,7 @@ class UsersAndGroup(object):
     _ARRAY_FIELDS = ('memberOf')
     _IGNORE_KEYS = ('sAMAccountType', 'systemUser')
     _UNIX_KEYS = ('uidNumber', 'loginShell', 'unixHomeDirectory', 'gidNumber')
+    _NON_EDIT_PARAMETERS = ('primaryGroupID')
 
     _IGNORE_GROUPS = (
         'Enterprise Read-Only Domain Controllers',
@@ -299,7 +300,7 @@ class UsersAndGroup(object):
                 changePassword = True
             else:
                 if key in adData:
-                    if userData[key] != adData[key]:
+                    if userData[key] != adData[key] and key not in self._NON_EDIT_PARAMETERS:
                         changedKeys.append(key)
                         ldif.append('-')
                         ldif.append('replace: %s' % key)
